@@ -1,7 +1,10 @@
-import requests
 import json
 
-from requests.auth import HTTPBasicAuth
+try:
+    import requests
+    from requests.auth import HTTPBasicAuth
+except:
+    pass
 
 class IntercomBaseModel(object):
 
