@@ -1,6 +1,3 @@
-import requests
-import json
-
 from models import *
 
 INTERCOM_API_BASE_URL = "https://api.intercom.io/"
